[−][src]Module input_device::event
The Event enum and assorted supporting types.
Re-exports
pub use crate::DeviceId; |
Structs
| ButtonId | Identifier for a specific button on some device. |
| KeyboardInput | Describes a keyboard input event. |
| ModifiersState | Represents the current state of the keyboard modifiers |
| PhysicalPosition | A position represented in physical pixels. |
| Touch | Represents a touch event |
Enums
| ElementState | Describes the input state of a key. |
| Event | Represents raw hardware events that are not associated with any particular window. |
| Force | Describes the force of a touch event |
| MouseButton | Describes a button of a mouse controller. |
| MouseScrollDelta | Describes a difference in the mouse scroll wheel state. |
| TouchPhase | Describes touch-screen input state. |
| VirtualKeyCode | Symbolic name for a keyboard key. |
Type Definitions
| AxisId | Identifier for a specific analog axis on some device. |
| ScanCode | Hardware-dependent keyboard scan code. |